@@ -57,14 +57,6 @@
         <source>C&amp;hoose</source>
         <translation type="unfinished">&amp;Izaberite</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation type="unfinished">Adrese pošiljalaca</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation type="unfinished">Adrese primalaca</translation>
-    </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">Ovo su vaše Bitcoin adrese za slanje novca. Uvijek provjerite iznos i adresu primaoca prije slanja novca.</translation>
@@ -751,10 +743,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Fee:</source>
         <translation type="unfinished">Naknada:</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Prašina:</translation>
-    </message>
     <message>
         <source>After Fee:</source>
         <translation type="unfinished">Poslije Naknade:</translation>
@@ -819,10 +807,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Copy bytes</source>
         <translation type="unfinished">Kopiraj bajte</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopiraj prašinu</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopiraj promjenu</translation>
@@ -831,18 +815,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>(%1 locked)</source>
         <translation type="unfinished">(%1 zaključano)</translation>
     </message>
-    <message>
-        <source>yes</source>
-        <translation type="unfinished">da</translation>
-    </message>
-    <message>
-        <source>no</source>
-        <translation type="unfinished">ne</translation>
-    </message>
-    <message>
-        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
-        <translation type="unfinished">Ova naljepnica postaje crvena ako bilo koji primatelj primi količinu manju od trenutnog praga prašine.</translation>
-    </message>
     <message>
         <source>Can vary +/- %1 satoshi(s) per input.</source>
         <translation type="unfinished">Može varirati +/- %1 satoshi (a) po upisu vrijednosti.</translation>
@@ -941,22 +913,10 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Make Blank Wallet</source>
         <translation type="unfinished">Napravi Prazan Novčanik</translation>
     </message>
-    <message>
-        <source>Use descriptors for scriptPubKey management</source>
-        <translation type="unfinished">Koristite deskriptore za upravljanje scriptPubKey</translation>
-    </message>
-    <message>
-        <source>Descriptor Wallet</source>
-        <translation type="unfinished">Deskriptor Novčanik</translation>
-    </message>
     <message>
         <source>Create</source>
         <translation type="unfinished">Napravi</translation>
     </message>
-    <message>
-        <source>Compiled without sqlite support (required for descriptor wallets)</source>
-        <translation type="unfinished">Sastavljeno bez podrške za sqlite (potrebno za deskriptorske novčanike)</translation>
-    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -1420,10 +1380,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Hide</source>
         <translation type="unfinished">Sakrij</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Prašina:</translation>
-    </message>
     <message>
         <source>Copy quantity</source>
         <translation type="unfinished">Kopiraj količinu</translation>
@@ -1444,10 +1400,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Copy bytes</source>
         <translation type="unfinished">Kopiraj bajte</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopiraj prašinu</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopiraj promjenu</translation>
@@ -1670,10 +1622,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Transaction amounts must not be negative</source>
         <translation type="unfinished">Iznosi transakcija ne smiju biti negativni</translation>
     </message>
-    <message>
-        <source>Transaction has too long of a mempool chain</source>
-        <translation type="unfinished">Transakcija ima predugačak mempool lanac </translation>
-    </message>
     <message>
         <source>Transaction must have at least one recipient</source>
         <translation type="unfinished">Transakcija mora imati najmanje jednog primaoca</translation>
