@@ -57,14 +57,6 @@
         <source>C&amp;hoose</source>
         <translation type="unfinished">V&amp;ali</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation type="unfinished">Saatvad aadressid</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation type="unfinished">Vastuvõtvad aadressid</translation>
-    </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">Need on sinu Bitcoin aadressid maksete saatmiseks. Ennem müntide saatmist kontrolli alati summat ja makse saaja aadressi.</translation>
@@ -582,10 +574,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Fee:</source>
         <translation type="unfinished">Tasu:</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Puru:</translation>
-    </message>
     <message>
         <source>After Fee:</source>
         <translation type="unfinished">Peale tehingutasu:</translation>
@@ -642,10 +630,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Copy bytes</source>
         <translation type="unfinished">Kopeeri baidid</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopeeri puru</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopeeri vahetusraha</translation>
@@ -654,14 +638,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>(%1 locked)</source>
         <translation type="unfinished">(%1 lukustatud)</translation>
     </message>
-    <message>
-        <source>yes</source>
-        <translation type="unfinished">jah</translation>
-    </message>
-    <message>
-        <source>no</source>
-        <translation type="unfinished">ei</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation type="unfinished">(silt puudub)</translation>
@@ -950,6 +926,10 @@ Signing is only possible with addresses of the type 'legacy'.</source>
     </context>
 <context>
     <name>PSBTOperationsDialog</name>
+    <message>
+        <source>own address</source>
+        <translation type="unfinished">oma aadress</translation>
+    </message>
     <message>
         <source>or</source>
         <translation type="unfinished">või</translation>
@@ -1294,10 +1274,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Clear all fields of the form.</source>
         <translation type="unfinished">Puhasta kõik vormi väljad.</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Puru:</translation>
-    </message>
     <message>
         <source>Clear &amp;All</source>
         <translation type="unfinished">Puhasta &amp;Kõik</translation>
@@ -1330,10 +1306,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Copy bytes</source>
         <translation type="unfinished">Kopeeri baidid</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopeeri puru</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopeeri vahetusraha</translation>
@@ -1697,10 +1669,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Sent to</source>
         <translation type="unfinished">Saadetud</translation>
     </message>
-    <message>
-        <source>Payment to yourself</source>
-        <translation type="unfinished">Makse iseendale</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Mine'itud</translation>
@@ -1760,10 +1728,6 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Sent to</source>
         <translation type="unfinished">Saadetud</translation>
     </message>
-    <message>
-        <source>To yourself</source>
-        <translation type="unfinished">Iseendale</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Mine'itud</translation>
