@@ -57,14 +57,6 @@
         <source>C&amp;hoose</source>
         <translation type="unfinished">&amp;Aukeratu</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation type="unfinished">Helbideak bidaltzen</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation type="unfinished">Helbideak jasotzen</translation>
-    </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">Hauek dira zuk dirua jaso dezaketen Bitcoin helbideak. Egiaztatu beti diru-kopurua eta dirua jasoko duen helbidea zuzen egon daitezen, txanponak bidali baino lehen.</translation>
@@ -738,10 +730,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Fee:</source>
         <translation type="unfinished">Ordainketa:</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Hautsa:</translation>
-    </message>
     <message>
         <source>After Fee:</source>
         <translation type="unfinished">Ordaindu ondoren:</translation>
@@ -806,10 +794,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Copy bytes</source>
         <translation type="unfinished">Kopiatu byte-ak</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopiatu hautsa</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopiatu aldaketa</translation>
@@ -818,14 +802,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>(%1 locked)</source>
         <translation type="unfinished">(%1 blokeatuta)</translation>
     </message>
-    <message>
-        <source>yes</source>
-        <translation type="unfinished">bai</translation>
-    </message>
-    <message>
-        <source>no</source>
-        <translation type="unfinished">ez</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation type="unfinished">(izendapenik ez)</translation>
@@ -943,10 +919,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Make Blank Wallet</source>
         <translation type="unfinished">Egin diruzorro hutsa...</translation>
     </message>
-    <message>
-        <source>Descriptor Wallet</source>
-        <translation type="unfinished">Deskriptorearen zorroa</translation>
-    </message>
     <message>
         <source>External signer</source>
         <translation type="unfinished">Kanpo sinatzailea</translation>
@@ -1330,6 +1302,10 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>PSBT saved to disk.</source>
         <translation type="unfinished">PSBT diskoan gorde da.</translation>
     </message>
+    <message>
+        <source>own address</source>
+        <translation type="unfinished">zure helbidea</translation>
+    </message>
     <message>
         <source>Total Amount</source>
         <translation type="unfinished">Kopuru osoa</translation>
@@ -1711,10 +1687,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Clear all fields of the form.</source>
         <translation type="unfinished">Garbitu formularioko eremu guztiak.</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Hautsa:</translation>
-    </message>
     <message>
         <source>Choose…</source>
         <translation type="unfinished">Aukeratu...</translation>
@@ -1751,10 +1723,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Copy bytes</source>
         <translation type="unfinished">Kopiatu byte-ak</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopiatu hautsa</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopiatu aldaketa</translation>
@@ -2051,10 +2019,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Sent to</source>
         <translation type="unfinished">Hona bidalia</translation>
     </message>
-    <message>
-        <source>Payment to yourself</source>
-        <translation type="unfinished">Zure buruarentzat ordainketa</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Meatua</translation>
@@ -2118,10 +2082,6 @@ Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
         <source>Sent to</source>
         <translation type="unfinished">Hona bidalia</translation>
     </message>
-    <message>
-        <source>To yourself</source>
-        <translation type="unfinished">Zeure buruari</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Meatua</translation>
