@@ -57,14 +57,6 @@
         <source>C&amp;hoose</source>
         <translation type="unfinished">&amp;Escoller</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation type="unfinished">Enviando enderezos</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation type="unfinished">Recibindo enderezos</translation>
-    </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">Estas son as túas direccións Bitcoin para enviar pagos. Revisa sempre a cantidade e a dirección receptora antes de enviar moedas.</translation>
@@ -91,11 +83,24 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Export Address List</source>
         <translation type="unfinished">Exportar Lista de Enderezos</translation>
     </message>
+    <message>
+        <source>Comma separated file</source>
+        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
+        <translation type="unfinished">Ficheiro separado por comas</translation>
+    </message>
     <message>
         <source>There was an error trying to save the address list to %1. Please try again.</source>
         <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
         <translation type="unfinished">Houbo un erro tentando gardar a lista de enderezos en %1. Por favor proba de novo.</translation>
     </message>
+    <message>
+        <source>Sending addresses - %1</source>
+        <translation type="unfinished">Enviando enderezos - %1</translation>
+    </message>
+    <message>
+        <source>Receiving addresses - %1</source>
+        <translation type="unfinished">Recibindo enderezos - %1</translation>
+    </message>
     <message>
         <source>Exporting Failed</source>
         <translation type="unfinished">Exportación falida</translation>
@@ -218,10 +223,22 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation type="unfinished">O contrasinal introducido para a desencriptación do moedeiro foi incorrecto.</translation>
     </message>
+    <message>
+        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
+        <translation type="unfinished">A frase de acceso introducida para o descifrado da carteira é incorrecta. Contén un carácter nulo (é dicir, un byte cero). Se a frase de paso se estableceu cunha versión deste software anterior á 25.0, téntao de novo con só os caracteres ata, pero sen incluír, o primeiro carácter nulo. Se se realiza correctamente, establece unha nova frase de acceso para evitar este problema no futuro.</translation>
+    </message>
     <message>
         <source>Wallet passphrase was successfully changed.</source>
         <translation type="unfinished">Cambiouse con éxito o contrasinal do moedeiro.</translation>
     </message>
+    <message>
+        <source>Passphrase change failed</source>
+        <translation type="unfinished">Produciuse un erro no cambio de frase de contrasinal</translation>
+    </message>
+    <message>
+        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
+        <translation type="unfinished">A contrasinal antiga introducida para o descifrado da carteira é incorrecta. Contén un carácter nulo (é dicir, un byte cero). Se a frase de paso se estableceu cunha versión deste software anterior á 25.0, téntao de novo con só os caracteres ata, pero sen incluír, o primeiro carácter nulo.</translation>
+    </message>
     <message>
         <source>Warning: The Caps Lock key is on!</source>
         <translation type="unfinished">Aviso: O Bloqueo de Maiúsculas está activo!</translation>
@@ -240,13 +257,33 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
 </context>
 <context>
     <name>BitcoinApplication</name>
+    <message>
+        <source>Settings file %1 might be corrupt or invalid.</source>
+        <translation type="unfinished">O ficheiro de configuración %1 pode estar danado ou non válido.</translation>
+    </message>
+    <message>
+        <source>Runaway exception</source>
+        <translation type="unfinished">Excepción de fuga</translation>
+    </message>
+    <message>
+        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
+        <translation type="unfinished">Produciuse un erro fatal. %1 xa non pode continuar con seguridade e sairá.</translation>
+    </message>
     <message>
         <source>Internal error</source>
         <translation type="unfinished">Erro interno</translation>
     </message>
-    </context>
+    <message>
+        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
+        <translation type="unfinished">Produciuse un erro interno. %1 tentará continuar con seguridade. Este é un erro inesperado que se pode informar como se describe a continuación.</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
+    <message>
+        <source>%1 didn't yet exit safely…</source>
+        <translation type="unfinished">%1 aínda non saíu con seguridade...</translation>
+    </message>
     <message>
         <source>unknown</source>
         <translation type="unfinished">descoñecido</translation>
@@ -389,10 +426,22 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>&amp;Options…</source>
         <translation type="unfinished">&amp;Opcións...</translation>
     </message>
+    <message>
+        <source>&amp;Encrypt Wallet…</source>
+        <translation type="unfinished">&amp;Cifrar carteira...</translation>
+    </message>
     <message>
         <source>Encrypt the private keys that belong to your wallet</source>
         <translation type="unfinished">Encriptar as claves privadas que pertencen ao teu moedeiro</translation>
     </message>
+    <message>
+        <source>&amp;Backup Wallet…</source>
+        <translation type="unfinished">&amp;Copia de seguranza da carteira...</translation>
+    </message>
+    <message>
+        <source>&amp;Change Passphrase…</source>
+        <translation type="unfinished">&amp;Cambiar a frase de contrasinal...</translation>
+    </message>
     <message>
         <source>Sign messages with your Bitcoin addresses to prove you own them</source>
         <translation type="unfinished">Asina mensaxes cos teus enderezos Bitcoin para probar que che pertencen</translation>
@@ -632,10 +681,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Fee:</source>
         <translation type="unfinished">Taxa:</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">po:</translation>
-    </message>
     <message>
         <source>After Fee:</source>
         <translation type="unfinished">Despois de taxas:</translation>
@@ -704,10 +749,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Copy bytes</source>
         <translation type="unfinished">Copiar bytes</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Copiar po</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Copiar cambio</translation>
@@ -716,18 +757,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>(%1 locked)</source>
         <translation type="unfinished">(%1 bloqueado)</translation>
     </message>
-    <message>
-        <source>yes</source>
-        <translation type="unfinished">si</translation>
-    </message>
-    <message>
-        <source>no</source>
-        <translation type="unfinished">non</translation>
-    </message>
-    <message>
-        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
-        <translation type="unfinished">Esta etiqueta tórnase vermella se algún receptor recibe unha cantidade máis pequena que o actual límite de po.</translation>
-    </message>
     <message>
         <source>Can vary +/- %1 satoshi(s) per input.</source>
         <translation type="unfinished">Pode variar +/- %1 satoshi(s) por entrada.</translation>
@@ -1157,6 +1186,10 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Close</source>
         <translation type="unfinished">Pechar</translation>
     </message>
+    <message>
+        <source>own address</source>
+        <translation type="unfinished">dirección propia</translation>
+    </message>
     </context>
 <context>
     <name>PaymentServer</name>
@@ -1429,10 +1462,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Clear all fields of the form.</source>
         <translation type="unfinished">Limpar tódolos campos do formulario</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">po:</translation>
-    </message>
     <message>
         <source>Clear &amp;All</source>
         <translation type="unfinished">Limpar &amp;Todo</translation>
@@ -1465,10 +1494,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Copy bytes</source>
         <translation type="unfinished">Copiar bytes</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Copiar po</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Copiar cambio</translation>
@@ -1828,10 +1853,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Sent to</source>
         <translation type="unfinished">Enviado a</translation>
     </message>
-    <message>
-        <source>Payment to yourself</source>
-        <translation type="unfinished">Pago a ti mesmo</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Minado</translation>
@@ -1891,10 +1912,6 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Sent to</source>
         <translation type="unfinished">Enviado a</translation>
     </message>
-    <message>
-        <source>To yourself</source>
-        <translation type="unfinished">A ti mesmo</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Minado</translation>
@@ -1915,6 +1932,11 @@ Firmar é posible unicamente con enderezos de tipo 'legacy'.</translation>
         <source>Export Transaction History</source>
         <translation type="unfinished">Exportar Historial de Transaccións</translation>
     </message>
+    <message>
+        <source>Comma separated file</source>
+        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
+        <translation type="unfinished">Ficheiro separado por comas</translation>
+    </message>
     <message>
         <source>Confirmed</source>
         <translation type="unfinished">Confirmado</translation>
