@@ -53,14 +53,6 @@
         <source>C&amp;hoose</source>
         <translation type="unfinished">С&amp;онго</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation type="unfinished">Илгээх хаягууд</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation type="unfinished">Хүлээн авах хаяг</translation>
-    </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">Эдгээр Биткойн хаягууд нь илгээх хаягууд. Хүлээн авах хаяг болон тоо хэмжээг илгээхээсээ өмнө сайн нягталж үзэж байна уу</translation>
@@ -955,10 +947,6 @@
         <source>Sent to</source>
         <translation type="unfinished">Явуулсан хаяг</translation>
     </message>
-    <message>
-        <source>Payment to yourself</source>
-        <translation type="unfinished">Ѳѳрлүүгээ хийсэн тѳлбѳр</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Олборлогдсон</translation>
@@ -1022,10 +1010,6 @@
         <source>Sent to</source>
         <translation type="unfinished">Явуулсан хаяг</translation>
     </message>
-    <message>
-        <source>To yourself</source>
-        <translation type="unfinished">Ѳѳрлүүгээ</translation>
-    </message>
     <message>
         <source>Mined</source>
         <translation type="unfinished">Олборлогдсон</translation>
