@@ -57,14 +57,6 @@
         <source>C&amp;hoose</source>
         <translation type="unfinished">Ô&amp;bier</translation>
     </message>
-    <message>
-        <source>Sending addresses</source>
-        <translation type="unfinished">Adresy posyłaniŏ</translation>
-    </message>
-    <message>
-        <source>Receiving addresses</source>
-        <translation type="unfinished">Adresy ôdbiyraniŏ</translation>
-    </message>
     <message>
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">Tukej sōm adresy Bitcoin na kere posyłŏsz płaty. Dycki wybaduj wielość i adresã ôdbiyrŏcza przed posłaniym mōnet.</translation>
@@ -540,10 +532,6 @@
         <source>Fee:</source>
         <translation type="unfinished">Ôpłŏcka:</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Sztaub:</translation>
-    </message>
     <message>
         <source>After Fee:</source>
         <translation type="unfinished">Po ôpłŏcce:</translation>
@@ -608,10 +596,6 @@
         <source>Copy bytes</source>
         <translation type="unfinished">Kopiyruj wielość bajtōw</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopiyruj sztaub</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopiyruj wydŏwkã</translation>
@@ -620,18 +604,6 @@
         <source>(%1 locked)</source>
         <translation type="unfinished">(%1 zaszperowane)</translation>
     </message>
-    <message>
-        <source>yes</source>
-        <translation type="unfinished">ja</translation>
-    </message>
-    <message>
-        <source>no</source>
-        <translation type="unfinished">niy</translation>
-    </message>
-    <message>
-        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
-        <translation type="unfinished">Ta etyketa stŏwŏ sie czyrwōnŏ jeźli keryś z ôdbiyrŏczy dostŏwŏ kwotã myńszõ aniżeli terŏźny prōg sztaubu.</translation>
-    </message>
     <message>
         <source>Can vary +/- %1 satoshi(s) per input.</source>
         <translation type="unfinished">Chwiyrŏ sie +/- %1 satoshi na wchōd.</translation>
@@ -1360,10 +1332,6 @@
         <source>Custom:</source>
         <translation type="unfinished">Włŏsne:</translation>
     </message>
-    <message>
-        <source>Dust:</source>
-        <translation type="unfinished">Sztaub:</translation>
-    </message>
     <message>
         <source>Balance:</source>
         <translation type="unfinished">Saldo:</translation>
@@ -1388,10 +1356,6 @@
         <source>Copy bytes</source>
         <translation type="unfinished">Kopiyruj wielość bajtōw</translation>
     </message>
-    <message>
-        <source>Copy dust</source>
-        <translation type="unfinished">Kopiyruj sztaub</translation>
-    </message>
     <message>
         <source>Copy change</source>
         <translation type="unfinished">Kopiyruj wydŏwkã</translation>
@@ -1556,10 +1520,6 @@
         <source>Received from</source>
         <translation type="unfinished">Ôdebrane ôd</translation>
     </message>
-    <message>
-        <source>Payment to yourself</source>
-        <translation type="unfinished">Płat do siebie</translation>
-    </message>
     <message>
         <source>(no label)</source>
         <translation type="unfinished">(chyba etykety)</translation>
