@@ -1,14 +1,20 @@
 // Copyright (c) 2009-2010 Satoshi Nakamoto
-// Copyright (c) 2009-2021 The Bitcoin Core developers
+// Copyright (c) 2009-present The Bitcoin Core developers
 // Distributed under the MIT software license, see the accompanying
 // file COPYING or http://www.opensource.org/licenses/mit-license.php.
 
 #include <script/script.h>
 
+#include <crypto/common.h>
+#include <hash.h>
+#include <uint256.h>
+#include <util/hash_type.h>
 #include <util/strencodings.h>
 
 #include <string>
 
+CScriptID::CScriptID(const CScript& in) : BaseHash(Hash160(in)) {}
+
 std::string GetOpName(opcodetype opcode)
 {
     switch (opcode)
