@@ -3,30 +3,27 @@
 // file COPYING or http://www.opensource.org/licenses/mit-license.php.
 
 #include <chainparams.h>
-#include <core_io.h>
 #include <rpc/client.h>
 #include <rpc/util.h>
 #include <test/fuzz/fuzz.h>
+#include <util/chaintype.h>
 
 #include <limits>
 #include <string>
 
 void initialize_parse_univalue()
 {
-    SelectParams(CBaseChainParams::REGTEST);
+    SelectParams(ChainType::REGTEST);
 }
 
-FUZZ_TARGET_INIT(parse_univalue, initialize_parse_univalue)
+FUZZ_TARGET(parse_univalue, .init = initialize_parse_univalue)
 {
     const std::string random_string(buffer.begin(), buffer.end());
     bool valid = true;
     const UniValue univalue = [&] {
-        try {
-            return ParseNonRFCJSONValue(random_string);
-        } catch (const std::runtime_error&) {
-            valid = false;
-            return UniValue{};
-        }
+        UniValue uv;
+        if (!uv.read(random_string)) valid = false;
+        return valid ? uv : UniValue{};
     }();
     if (!valid) {
         return;
@@ -59,12 +56,6 @@ FUZZ_TARGET_INIT(parse_univalue, initialize_parse_univalue)
         (void)ParseHexO(univalue, random_string);
     } catch (const UniValue&) {
     }
-    try {
-        (void)ParseHexUV(univalue, "A");
-        (void)ParseHexUV(univalue, random_string);
-    } catch (const UniValue&) {
-    } catch (const std::runtime_error&) {
-    }
     try {
         (void)ParseHexV(univalue, "A");
     } catch (const UniValue&) {
@@ -76,8 +67,8 @@ FUZZ_TARGET_INIT(parse_univalue, initialize_parse_univalue)
     } catch (const std::runtime_error&) {
     }
     try {
-        (void)ParseSighashString(univalue);
-    } catch (const std::runtime_error&) {
+        if (univalue.isNull() || univalue.isStr()) (void)ParseSighashString(univalue);
+    } catch (const UniValue&) {
     }
     try {
         (void)AmountFromValue(univalue);
