@@ -4,6 +4,7 @@
 
 #include <consensus/amount.h>
 #include <policy/fees.h>
+#include <script/solver.h>
 #include <validation.h>
 #include <wallet/coincontrol.h>
 #include <wallet/spend.h>
@@ -26,14 +27,13 @@ BOOST_FIXTURE_TEST_CASE(SubtractFee, TestChain100Setup)
     // leftover input amount which would have been change to the recipient
     // instead of the miner.
     auto check_tx = [&wallet](CAmount leftover_input_amount) {
-        CRecipient recipient{GetScriptForRawPubKey({}), 50 * COIN - leftover_input_amount, /*subtract_fee=*/true};
-        constexpr int RANDOM_CHANGE_POSITION = -1;
+        CRecipient recipient{PubKeyDestination({}), 50 * COIN - leftover_input_amount, /*subtract_fee=*/true};
         CCoinControl coin_control;
         coin_control.m_feerate.emplace(10000);
         coin_control.fOverrideFeeRate = true;
         // We need to use a change type with high cost of change so that the leftover amount will be dropped to fee instead of added as a change output
         coin_control.m_change_type = OutputType::LEGACY;
-        auto res = CreateTransaction(*wallet, {recipient}, RANDOM_CHANGE_POSITION, coin_control);
+        auto res = CreateTransaction(*wallet, {recipient}, /*change_pos=*/std::nullopt, coin_control);
         BOOST_CHECK(res);
         const auto& txr = *res;
         BOOST_CHECK_EQUAL(txr.tx->vout.size(), 1);
@@ -61,57 +61,6 @@ BOOST_FIXTURE_TEST_CASE(SubtractFee, TestChain100Setup)
     BOOST_CHECK_EQUAL(fee, check_tx(fee + 123));
 }
 
-static void TestFillInputToWeight(int64_t additional_weight, std::vector<int64_t> expected_stack_sizes)
-{
-    static const int64_t EMPTY_INPUT_WEIGHT = GetTransactionInputWeight(CTxIn());
-
-    CTxIn input;
-    int64_t target_weight = EMPTY_INPUT_WEIGHT + additional_weight;
-    BOOST_CHECK(FillInputToWeight(input, target_weight));
-    BOOST_CHECK_EQUAL(GetTransactionInputWeight(input), target_weight);
-    BOOST_CHECK_EQUAL(input.scriptWitness.stack.size(), expected_stack_sizes.size());
-    for (unsigned int i = 0; i < expected_stack_sizes.size(); ++i) {
-        BOOST_CHECK_EQUAL(input.scriptWitness.stack[i].size(), expected_stack_sizes[i]);
-    }
-}
-
-BOOST_FIXTURE_TEST_CASE(FillInputToWeightTest, BasicTestingSetup)
-{
-    {
-        // Less than or equal minimum of 165 should not add any witness data
-        CTxIn input;
-        BOOST_CHECK(!FillInputToWeight(input, -1));
-        BOOST_CHECK_EQUAL(GetTransactionInputWeight(input), 165);
-        BOOST_CHECK_EQUAL(input.scriptWitness.stack.size(), 0);
-        BOOST_CHECK(!FillInputToWeight(input, 0));
-        BOOST_CHECK_EQUAL(GetTransactionInputWeight(input), 165);
-        BOOST_CHECK_EQUAL(input.scriptWitness.stack.size(), 0);
-        BOOST_CHECK(!FillInputToWeight(input, 164));
-        BOOST_CHECK_EQUAL(GetTransactionInputWeight(input), 165);
-        BOOST_CHECK_EQUAL(input.scriptWitness.stack.size(), 0);
-        BOOST_CHECK(FillInputToWeight(input, 165));
-        BOOST_CHECK_EQUAL(GetTransactionInputWeight(input), 165);
-        BOOST_CHECK_EQUAL(input.scriptWitness.stack.size(), 0);
-    }
-
-    // Make sure we can add at least one weight
-    TestFillInputToWeight(1, {0});
-
-    // 1 byte compact size uint boundary
-    TestFillInputToWeight(252, {251});
-    TestFillInputToWeight(253, {83, 168});
-    TestFillInputToWeight(262, {86, 174});
-    TestFillInputToWeight(263, {260});
-
-    // 3 byte compact size uint boundary
-    TestFillInputToWeight(65535, {65532});
-    TestFillInputToWeight(65536, {21842, 43688});
-    TestFillInputToWeight(65545, {21845, 43694});
-    TestFillInputToWeight(65546, {65541});
-
-    // Note: We don't test the next boundary because of memory allocation constraints.
-}
-
 BOOST_FIXTURE_TEST_CASE(wallet_duplicated_preset_inputs_test, TestChain100Setup)
 {
     // Verify that the wallet's Coin Selection process does not include pre-selected inputs twice in a transaction.
@@ -128,7 +77,7 @@ BOOST_FIXTURE_TEST_CASE(wallet_duplicated_preset_inputs_test, TestChain100Setup)
 
     // Try to create a tx that spends more than what preset inputs + wallet selected inputs are covering for.
     // The wallet can cover up to 200 BTC, and the tx target is 299 BTC.
-    std::vector<CRecipient> recipients = {{GetScriptForDestination(*Assert(wallet->GetNewDestination(OutputType::BECH32, "dummy"))),
+    std::vector<CRecipient> recipients{{*Assert(wallet->GetNewDestination(OutputType::BECH32, "dummy")),
                                            /*nAmount=*/299 * COIN, /*fSubtractFeeFromAmount=*/true}};
     CCoinControl coin_control;
     coin_control.m_allow_other_inputs = true;
@@ -148,12 +97,12 @@ BOOST_FIXTURE_TEST_CASE(wallet_duplicated_preset_inputs_test, TestChain100Setup)
     // so that the recipient's amount is no longer equal to the user's selected target of 299 BTC.
 
     // First case, use 'subtract_fee_from_outputs=true'
-    util::Result<CreatedTransactionResult> res_tx = CreateTransaction(*wallet, recipients, /*change_pos*/-1, coin_control);
+    util::Result<CreatedTransactionResult> res_tx = CreateTransaction(*wallet, recipients, /*change_pos=*/std::nullopt, coin_control);
     BOOST_CHECK(!res_tx.has_value());
 
     // Second case, don't use 'subtract_fee_from_outputs'.
     recipients[0].fSubtractFeeFromAmount = false;
-    res_tx = CreateTransaction(*wallet, recipients, /*change_pos*/-1, coin_control);
+    res_tx = CreateTransaction(*wallet, recipients, /*change_pos=*/std::nullopt, coin_control);
     BOOST_CHECK(!res_tx.has_value());
 }
 
